<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>Ein einfacher, benutzerfreundlicher Jabber/XMPP client</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>Lizenz:</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="vanished">Quellcode auf GitHub</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>Quellcode online einsehen</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation>Probleme melden</translation>
    </message>
</context>
<context>
    <name>AboutPage</name>
    <message>
        <source>About</source>
        <translation type="vanished">Über</translation>
    </message>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="vanished">Ein einfacher, benutzerfreundlicher Jabber/XMPP client</translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="vanished">Lizenz:</translation>
    </message>
    <message>
        <source>Sourcecode on GitHub</source>
        <translation type="vanished">Quellcode auf GitHub</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Schließen</translation>
    </message>
</context>
<context>
    <name>AboutSheet</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="vanished">Ein einfacher, benutzerfreundlicher Jabber/XMPP client</translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="vanished">Lizenz:</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="vanished">Quellcode auf GitHub</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
    <message>
        <source>Delete account completely</source>
        <translation type="vanished">Konto vollständig löschen</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="vanished">Ihr Konto wird vollständig gelöscht sein, d.h. von dieser Anwendung und vom Server.

Sie werden Ihr Konto nicht mehr benutzen können!</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Löschen</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientConfirmationPage</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="vanished">Konto aus dieser App entfernen</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
You won&apos;t be able to get your credentials back!
Make sure that you have backed up those if you want to use your account later.</source>
        <translation type="vanished">Ihr Konto wird aus dieser App entfernt sein.
Sie werden nicht in der Lage sein, Ihre Zugangsdaten zurückzubekommen!
Stellen Sie sicher, dass Sie diese gesichert haben, wenn Sie Ihr Konto später benutzen möchten.</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Entfernen</translation>
    </message>
</context>
<context>
    <name>AccountDeletionPage</name>
    <message>
        <source>Delete account</source>
        <translation type="vanished">Konto löschen</translation>
    </message>
    <message>
        <source>You can remove your account &lt;b&gt;%1&lt;/b&gt; only from this app or delete it completely. If you delete your account completely, you won&apos;t be able to use it with another app because it is also removed from the server.</source>
        <translation type="vanished">Sie können Ihr Konto &lt;b&gt;%1&lt;/b&gt; nur aus dieser App entfernen oder es komplett löschen. Wenn Sie Ihr Konto vollständig löschen, können Sie es nicht mehr mit einer anderen Anwendung verwenden, da es ebenfalls vom Server entfernt wird.</translation>
    </message>
    <message>
        <source>Remove from this app</source>
        <translation type="vanished">Aus dieser App entfernen</translation>
    </message>
    <message>
        <source>Delete completely</source>
        <translation type="vanished">Vollständig löschen</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation>Konto-Sicherheit</translation>
    </message>
    <message>
        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
        <translation>Erlaube das Hinzufügen neuer Geräte mit einem QR-Code, aber zeige das Passwort niemals als Text an. Diese Aktion kann nicht rückgängig gemacht werden. Sie sollten also überlegen, das Passwort vor der Verwendung anderweitig zu speichern.</translation>
    </message>
    <message>
        <source>Disable showing the password</source>
        <translation>Passwort nicht mehr anzeigen</translation>
    </message>
    <message>
        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
        <translation>Passwort in keiner Form verfügbar machen. Dies kann nicht rückgängig gemacht werden.</translation>
    </message>
    <message>
        <source>Disable showing the QR-Code and password</source>
        <translation>Passwort und QR-Code nicht mehr anzeigen</translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation>Konto auf ein anderes Gerät übertragen</translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation>Scannen Sie den QR-Code oder geben Sie die Anmeldedaten als Text auf einem anderen Gerät ein, um sich dort anzumelden.

Achtung!
Zeigen Sie diesen QR-Code niemals anderen Personen. Er würde unbegrenzten Zugang zu Ihrem Konto ermöglichen!</translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation>Chat-Adresse:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation>QR-Code ausblenden</translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation>Als QR-Code anzeigen</translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation>Text ausblenden</translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation>Als Text anzeigen</translation>
    </message>
    <message>
        <source>Copy JID</source>
        <translation>JID kopieren</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>Passwort kopieren</translation>
    </message>
</context>
<context>
    <name>BackButton</name>
    <message>
        <source>Navigate Back</source>
        <translation type="vanished">Zurück navigieren</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>Passwort ändern</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>Aktuelles Passwort:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Neues Passwort:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>Neues Passwort (erneut):</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>Die eingegebenen Passwörter stimmen nicht überein.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>Aktuelles Passwort ist ungültig.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation type="vanished">Sie müssen verbunden sein, um Ihr Passwort zu ändern.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>Nachdem Sie Ihr Passwort geändert haben, werden Sie es auf allen anderen Geräten neu eingeben müssen.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Password changed successfully</source>
        <translation>Passwort wurde erfolgreich geändert</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation>Änderung des Passworts ist fehlgeschlagen: %1</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Message copied to clipboard</source>
        <translation type="vanished">Nachricht wurde in die Zwischenablage kopiert</translation>
    </message>
    <message>
        <source>Copy Message</source>
        <translation type="vanished">Nachricht kopieren</translation>
    </message>
    <message>
        <source>Edit Message</source>
        <translation type="vanished">Nachricht bearbeiten</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>Versteckte Nachricht</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Download-Link kopieren</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation>Nachricht kopieren</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation>Nachricht bearbeiten</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation>URL zum Herunterladen kopieren</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation>Nachricht zitieren</translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation type="vanished">Nachricht verfassen</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="vanished">Senden</translation>
    </message>
    <message>
        <source>Please choose a file to upload</source>
        <translation type="vanished">Datei zum Hochladen auswählen</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Bild</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Ton</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">Dokument</translation>
    </message>
    <message>
        <source>Other file</source>
        <translation type="vanished">Andere Datei</translation>
    </message>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Eine Datei auswählen</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>Versteckte Nachricht senden</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation type="vanished">Titel für versteckte Nachricht</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation>Benachrichtigungen aktivieren</translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>Benachrichtigungen stummschalten</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation>Profil anzeigen</translation>
    </message>
    <message>
        <source>Multimedia settings</source>
        <translation type="vanished">Multimedia Einstellungen</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Schließen</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Weiter oben suchen</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Weiter unten suchen</translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="vanished">Alle Dateien</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation type="vanished">Nachricht kopieren</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation type="vanished">Nachricht bearbeiten</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Herunterladen-Link kopieren</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="vanished">Nachricht zitieren</translation>
    </message>
    <message>
        <source>Close message search bar</source>
        <translation>Suche schließen</translation>
    </message>
</context>
<context>
    <name>ChatPageSendingPane</name>
    <message>
        <source>Spoiler hint</source>
        <translation>Spoiler Hinweis</translation>
    </message>
    <message>
        <source>Close spoiler hint field</source>
        <translation>Spoiler-Feld ausblenden</translation>
    </message>
    <message>
        <source>Compose message</source>
        <translation>Nachricht verfassen</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation>Ihr Konto konnte nicht vom Server gelöscht werden. Daher wurde es auch nicht aus dieser App entfernt: %1</translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation>Sehr niedrig</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Niedrig</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>Very high</source>
        <translation>Sehr hoch</translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation>Feste Qualität</translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation>Feste Bitrate</translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation>Durchschnittliche Bitrate</translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation>Zwei Durchgänge</translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>ConnectionSettings</name>
    <message>
        <source>Connection settings</source>
        <translation>Verbindungseinstellungen</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Connection settings could not be changed</source>
        <translation>Verbindungseinstellungen konnten nicht geändert werden</translation>
    </message>
    <message>
        <source>Connection settings changed</source>
        <translation>Verbindungseinstellungen geändert</translation>
    </message>
</context>
<context>
    <name>ContextDrawer</name>
    <message>
        <source>Actions</source>
        <translation type="vanished">Aktionen</translation>
    </message>
</context>
<context>
    <name>CustomConnectionSettings</name>
    <message>
        <source>Hostname:</source>
        <translation>Host-Name:</translation>
    </message>
    <message>
        <source>The hostname must not contain blank spaces</source>
        <translation>Der Host-Name darf keine Leerzeichen enthalten</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Remove password completely</source>
        <translation>Passwort vollständig ausblenden</translation>
    </message>
    <message>
        <source>Your password will not be included in the QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation>Ihr Passwort wird nicht mehr im QR-Code enthalten sein.
Sie können die Anmeldung über den QR-Code nicht mehr verwenden, ohne Ihr Passwort erneut einzugeben, da diese Aktion nicht rückgängig gemacht werden kann!
Stellen Sie sicher, dass Sie das Passwort gesichert haben, wenn Sie Ihr Konto später verwenden möchten.</translation>
    </message>
    <message>
        <source>Remove password</source>
        <translation>Passwort ausblenden</translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Do not show password as text</source>
        <translation>Passwort nicht als Klartext anzeigen</translation>
    </message>
    <message>
        <source>Your password will not be shown as text anymore.
You won&apos;t be able to see your password as text again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation>Ihr Passwort wird nicht mehr als Text angezeigt werden.
Sie werden Ihr Passwort nicht mehr als Text sehen können, da diese Aktion nicht rückgängig gemacht werden kann!
Stellen Sie sicher, dass Sie es gesichert haben, wenn Sie sich später noch auf ihrem Konto anmelden wollen.</translation>
    </message>
    <message>
        <source>Do not show password</source>
        <translation>Passwort nicht anzeigen</translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation>Datei konnte nicht gespeichert werden: %1</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>Herunterladen fehlgeschlagen: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation type="vanished">Favoriten</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="vanished">Menschen</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation type="vanished">Natur</translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="vanished">Essen</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation type="vanished">Aktivitäten</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation type="vanished">Reisen</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation type="vanished">Gegenstände</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation type="vanished">Zeichen</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation type="vanished">Flaggen</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Suche</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation type="vanished">Emoji suchen</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>Bitte wählen Sie einen Chat aus, um zu beginnen</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Datei auswählen</translation>
    </message>
</context>
<context>
    <name>FileChooserMobile</name>
    <message>
        <source>go to parent folder</source>
        <translation type="vanished">zum übergeordneten Ordner wechseln</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Schließen</translation>
    </message>
    <message>
        <source>Go to parent folder</source>
        <translation type="vanished">In übergeordneten Ordner wechseln</translation>
    </message>
</context>
<context>
    <name>ForwardButton</name>
    <message>
        <source>Navigate Forward</source>
        <translation type="vanished">Vorwärts</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>Add Contact</source>
        <translation type="vanished">Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation type="vanished">Abmelden</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation type="vanished">Neuen Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="vanished">Zurück</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>Freunde einladen</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>Einladungslink wurde in die Zwischenablage kopiert</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Online</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Verbinde…</translation>
    </message>
    <message>
        <source>Transfer account</source>
        <translation type="vanished">Konto übertragen</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="vanished">Konto löschen</translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation>Gerät wechseln</translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>Could not send message, because not being connected.</source>
        <translation type="vanished">Die Nachricht konnte nicht gesendet werden, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>Could not add contact, because not being connected.</source>
        <translation type="vanished">Der Kontakt konnte nicht hinzugefügt werden, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>Could not remove contact, because not being connected.</source>
        <translation type="vanished">Der Kontakt konnte nicht entfernt werden, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">Konnte Nachricht nicht versenden, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation type="vanished">Konnte den Kontakt nicht hinzufügen, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation type="vanished">Konnte den Kontakt nicht entfernen, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>Der Link wird nach Aufbau der Verbindung geöffnet.</translation>
    </message>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation type="vanished">Konnte Datei nicht senden, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>No password found. Please enter it.</source>
        <translation type="vanished">Kein Password gefunden. Bitte gib es ein.</translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation>Kein gültiger QR-Code zum Anmelden gefunden.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation>Konto aus dieser App entfernen</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation>Ihr Konto wird aus dieser App entfernt.
Ihr Passwort wird gelöscht, stellen Sie sicher, dass es in einem Passwort-Manager gespeichert ist oder Sie es kennen!</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Your Jabber-ID:</source>
        <translation type="vanished">Deine Jabber-ID:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="vanished">user@beispiel.org</translation>
    </message>
    <message>
        <source>Your Password:</source>
        <translation type="vanished">Dein Passwort:</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Passwort</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Verbinden</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="vanished">Erneut versuchen</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Verbinden …</translation>
    </message>
    <message>
        <source>Log in</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>Anmelden mit deinem XMPP Account</translation>
    </message>
    <message>
        <source>Your diaspora*-ID:</source>
        <translation type="vanished">Deine diaspora*-ID:</translation>
    </message>
    <message>
        <source>user@diaspora.pod</source>
        <translation type="vanished">benutzer@diaspora.pod</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="vanished">Falscher Benutzername oder falsches Passwort.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="vanished">Konnte nicht zum Server verbinden. Überprüfen Sie Ihre Internetverbindung.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="vanished">Dieser Server unterstützt keine sicheren Verbindungen.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="vanished">Fehler bei der Herstellung einer sicheren Verbindung.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your JID again.</source>
        <translation type="vanished">Konnte den Servernamen nicht auflösen. Bitte überprüfen sie Ihre JID.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="vanished">Konnte nicht mit dem Server verbinden.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="vanished">Authentifizierungsprotokolle nicht vom Server unterstützt.</translation>
    </message>
    <message>
        <source>An unknown error occured; see log for details.</source>
        <translation type="vanished">Ein unbekannter Fehler ist aufgetreten: Sehen Sie die Logdatei für mehr Details ein.</translation>
    </message>
    <message>
        <source>Log in using a QR-Code</source>
        <translation type="vanished">Mit einem QR-Code anmelden</translation>
    </message>
    <message>
        <source>Connection settings</source>
        <translation>Verbindungseinstellungen</translation>
    </message>
</context>
<context>
    <name>LoginSettingsPage</name>
    <message>
        <source>Connection settings</source>
        <translation>Verbindungseinstellungen</translation>
    </message>
    <message>
        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
        <translation>Die Verbindungseinstellungen werden nach dem ersten erfolgreichem Login gespeichert. Wenn sie nicht funktionieren, wird die Anmeldeseite geöffnet.</translation>
    </message>
    <message>
        <source>Enable custom connection settings</source>
        <translation>Aktivieren der manuellen Verbindungseinstellungen</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Hostname:</source>
        <translation>Host-Name:</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>Bild aufnehmen</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Video aufnehmen</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>Stimme aufnehmen</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>Standort senden</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>Datei auswählen</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>Bild auswählen</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>Video auswählen</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>Audio-Datei auswählen</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>Dokument auswählen</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle Dateien</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation>Audio Dateien</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumente</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ton</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Standort</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Datei</translation>
    </message>
</context>
<context>
    <name>Message</name>
    <message>
        <source>Spoiler</source>
        <translation>Spoiler</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">Konnte Nachricht nicht versenden, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="vanished">Konnte Nachricht nicht korrigieren, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Versteckt</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Nachricht konnte nicht gesendet werden.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation>Nachrichtenkorrektur war nicht erfolgreich.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation>Ausstehend</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Gesendet</translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation>Angekommen</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation>Multimedia-Einstellungen</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Konfigurieren</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation>Bildaufnahme</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation>Audioaufnahme</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation>Videoaufnahme</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation>Audioeingabe</translation>
    </message>
    <message>
        <source>Container</source>
        <translation>Container</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ton</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Auflösung</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualität</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Abtastrate</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation>Bildrate</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Bereit</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Initialisiere…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Nicht verfügbar</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation>Aufnahme…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
</context>
<context>
    <name>MultimediaSettingsPage</name>
    <message>
        <source>Multimedia Settings</source>
        <translation type="vanished">Multimedia-Einstellungen</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="vanished">Konfigurieren</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation type="vanished">Bild Aufnahme</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation type="vanished">Audio Aufnahme</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="vanished">Video Aufnahme</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="vanished">Kamera</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation type="vanished">Audio Eingabe</translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="vanished">Container</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Bild</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Ton</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="vanished">Codec</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="vanished">Auflösung</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="vanished">Qualität</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="vanished">Abtastrate</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation type="vanished">Bildrate</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="vanished">Bereit</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation type="vanished">Initialisieren…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="vanished">Nicht verfügbar</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation type="vanished">Aufnahme…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="vanished">Pausiert</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Ready</source>
        <translation type="vanished">Bereit</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Initializieren…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Nicht verfügbar</translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation>Zeichne auf… %1</translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation>%1 pausiert</translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation>Passwort ausblenden</translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation>Sie können sich entscheiden, Ihr Passwort für &lt;b&gt;%1&lt;/b&gt; nur nicht mehr als Text anzuzeigen oder es vollständig aus der Kontoübertragung zu entfernen. Wenn Sie Ihr Passwort vollständig entfernen, können Sie die Kontoübertragung per QR-Code-Scan ohne Eingabe Ihres Passworts nicht mehr nutzen, da es auch aus dem QR-Code entfernt wird.</translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation>Passwort nicht als Klartext anzeigen</translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation>Vollständig entfernen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation>Als gelesen markieren</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Verfügbar</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation>Frei zum Chatten</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>Abwesend</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation>Nicht stören</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation>Für längere Zeit abwesend</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation type="vanished">Verfügbar</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Frei zum Chatten</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Abwesend</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">Nicht stören</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Für längere Zeit abwesend</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Offline</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Fehler</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="vanished">Unsichtbar</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation>Falscher Benutzername oder falsches Passwort.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation>Konnte nicht zum Server verbinden. Überprüfen Sie Ihre Internetverbindung.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation>Dieser Server unterstützt keine sicheren Verbindungen.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation>Fehler bei der Herstellung einer sicheren Verbindung.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
        <translation type="vanished">Konnte die Adresse des Servers nicht finden. Bitte überprüfen Sie Ihren Servernamen.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="obsolete">Konnte nicht mit dem Server verbinden.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation>Authentifizierungsprotokolle nicht vom Server unterstützt.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation>Dieser Server unterstützt keine Registrierung.</translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation>Der Server ist offline oder durch eine Firewall blockiert.</translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation>Die Verbindung konnte nicht aktualisiert werden.</translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation>Der Internetzugang ist nicht gestattet. Bitte überprüfen Sie die Internetzugangskonfiguration Ihres Systems.</translation>
    </message>
    <message>
        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
        <translation>Konnte nicht zum Server verbinden. Bitte überprüfe deine Internetverbindung oder den Server-Namen.</translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation>Fehler beim Generieren des QR-Codes: %1</translation>
    </message>
</context>
<context>
    <name>QrCodeOnboardingPage</name>
    <message>
        <source>Scan QR code</source>
        <translation>QR-Code scannen</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation>Erklärung anzeigen</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation>Ohne QR-Code fortfahren</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation>Scannen den QR-Code von deinem bestehendem Gerät, um dein Konto zu übertragen.</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Verbinde…</translation>
    </message>
</context>
<context>
    <name>QrCodeScanner</name>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation>Das Kamera-Format „%1“ wird nicht unterstüzt.</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation>Keine Kamera verfügbar.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation>Deine Kamera ist beschäftigt.
Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="vanished">QR-Code scannen</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="vanished">Keine Kamera verfügbar.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="vanished">Deine Kamera ist beschäftigt.
Versuche andere Programme, welche die Kamera verwenden, zu schließen.</translation>
    </message>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="vanished">Das Kamera-Format „%1“ wird nicht unterstüzt.</translation>
    </message>
    <message>
        <source>Logging in…</source>
        <translation type="vanished">Anmeldung…</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation type="vanished">Scannen Sie den QR-Code von Ihrem vorhandenen Gerät, um Ihr Konto zu übertragen.</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation type="vanished">Erklärung anzeigen</translation>
    </message>
    <message>
        <source>Scan</source>
        <translation type="vanished">Scannen</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="vanished">Ohne QR-Code fortfahren</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="vanished">Verbinden…</translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation>Einrichten</translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation>Ein neues Konto registrieren</translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation>Ein vorhandenes Konto verwenden</translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation type="vanished">Passwort erfolgreich geändert.</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="vanished">Änderung des Passworts ist fehlgeschlagen: %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation>Konto vollständig löschen</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation>Ihr Konto wird vollständig gelöscht sein, d.h. von dieser Anwendung und vom Server.
Sie werden Ihr Konto nicht mehr benutzen können!</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Add Contact</source>
        <translation type="vanished">Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation>Spitzname:</translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation>Jabber-ID:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation>benutzer@beispiel.org</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Neuen Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation>Dies wird auch eine Abonnement-Anfrage senden, um die Präsenz des Kontakts zu empfangen.</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation>Optionale Nachricht:</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation>Sagen Sie Ihrem Kontakt, wer Sie sind.</translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Error: Please check the JID.</source>
        <translation type="vanished">Fehler: Bitte überprüfen Sie die JID.</translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="vanished">Verfügbar</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Frei zum Chatten</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Abwesend</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">DnD (Nicht stören)</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Für längere Zeit abwesend</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Offline</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Fehler</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation type="vanished">Ungültig</translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation>Konnte den Kontakt nicht hinzufügen, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation>Konnte den Kontakt nicht entfernen, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Versteckte Nachricht</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation>Konnte den Kontakt nicht umbenennen, da keine Verbindung besteht.</translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Contacts</source>
        <translation>Kontakte</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Neuen Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Verbinden…</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation>Kontakte durchsuchen</translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Delete contact</source>
        <translation>Kontakt entfernen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;%1&gt; from your roster?</source>
        <translation type="vanished">Möchten Sie wirklich &lt;%1&gt; aus Ihrer Kontaktliste entfernen?</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation type="vanished">Möchten Sie wirklich den Kontakt &lt;b&gt;%1&lt;/b&gt; von Ihrer Kontaktliste entfernen?</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
        <translation>Möchtest du wirklich den Kontakt &lt;b&gt;%1&lt;/b&gt; aus deiner Kontaktliste entfernen?</translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation>Kontakt umbenennen</translation>
    </message>
    <message>
        <source>Edit name:</source>
        <translation type="vanished">Namen bearbeiten:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Caption</source>
        <translation>Beschriftung</translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation>Benutzerdefinierter Server</translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation>Keine Einschränkungen</translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation>%1 Tage</translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation>Passwort ändern</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation>Ändert das Passwort Ihres Kontos. Sie werden das neue Passwort auf allen anderen Geräten neu eingeben müssen.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation>Multimedia-Einstellungen</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation>Konfigurieren Sie die Einstellungen für Foto-, Video- und Audioaufnahmen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation>Konto-Sicherheit</translation>
    </message>
    <message>
        <source>configure whether this device can be used to log in on a new device</source>
        <translation type="vanished">Einstellen, ob dieses Gerät zum Anmelden an einem neuen Gerät verwendet werden kann</translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation>Konto aus Kaidan entfernen</translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation>Konto aus dieser App entfernen</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Konto löschen</translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation>Konto auf dem Server löschen</translation>
    </message>
    <message>
        <source>Connection Settings</source>
        <translation>Verbindungseinstellungen</translation>
    </message>
    <message>
        <source>Configure the hostname and port to connect to</source>
        <translation>Einstellen des Host-Namen und Ports der Verbindung zum Server</translation>
    </message>
    <message>
        <source>Configure whether this device can be used to log in on a new device</source>
        <translation>Einstellen, ob das Gerät das Passwort übertragen kann</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="vanished">Passwort ändern</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="vanished">Das Passwort Ihres Kontos ändern. Sie werden das neue Passwort auf allen anderen Geräten neu eingeben müssen.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="obsolete">Multimedia-Einstellungen</translation>
    </message>
</context>
<context>
    <name>SettingsSheet</name>
    <message>
        <source>Settings</source>
        <translation type="vanished">Einstellungen</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation>Genießen Sie freie Kommunikation auf jedem Gerät!</translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation>Fangen wir an</translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation>Abonnement-Anfrage</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation>Sie haben eine Abonnement-Anfrage von &lt;b&gt;%1&lt;/b&gt; erhalten. Wenn sie diese akzeptieren, hat dieser Account zugriff auf Ihren Präsenzstatus.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation>Ablehnen</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Annehmen</translation>
    </message>
</context>
<context>
    <name>ToolBarApplicationHeader</name>
    <message>
        <source>More Actions</source>
        <translation type="vanished">Mehr Aktionen</translation>
    </message>
</context>
<context>
    <name>ToolBarPageHeader</name>
    <message>
        <source>More Actions</source>
        <translation type="vanished">Mehr Aktionen</translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation>Konnte Datei nicht senden, da Sie nicht verbunden sind.</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="vanished">Datei</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Nachricht konnte nicht gesendet werden.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation>Profil</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation>Kontakt umbenennen</translation>
    </message>
    <message>
        <source>Show QR code</source>
        <translation>QR-Code anzeigen</translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation>Kontakt entfernen</translation>
    </message>
    <message>
        <source>Online devices</source>
        <translation>Verbundene Geräte</translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Spitzname</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-Mail</translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation>Geburtstag</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Website</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Successfully parsed command line input.</source>
        <translation type="vanished">Kommandozeileneingabe erfolgreich ausgewertet.</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation type="vanished">Abmelden</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="vanished">Über</translation>
    </message>
</context>
</TS>
